@@ -1,32 +1,57 @@
+/**
+ * Copyright (c) 2004-2011 QOS.ch
+ * All rights reserved.
+ *
+ * Permission is hereby granted, free  of charge, to any person obtaining
+ * a  copy  of this  software  and  associated  documentation files  (the
+ * "Software"), to  deal in  the Software without  restriction, including
+ * without limitation  the rights to  use, copy, modify,  merge, publish,
+ * distribute,  sublicense, and/or sell  copies of  the Software,  and to
+ * permit persons to whom the Software  is furnished to do so, subject to
+ * the following conditions:
+ *
+ * The  above  copyright  notice  and  this permission  notice  shall  be
+ * included in all copies or substantial portions of the Software.
+ *
+ * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
+ * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
+ * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
+ * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
+ * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ *
+ */
 package org.slf4j.ext;
 
 import org.slf4j.Logger;
 import org.slf4j.Marker;
+import org.slf4j.helpers.FormattingTuple;
 import org.slf4j.helpers.MessageFormatter;
 import org.slf4j.spi.LocationAwareLogger;
 
 /**
- * A helper class wrapping an {@link org.slf4j.Logger}
- * instance preserving location information if the wrapped
- * instance supports it.
+ * A helper class wrapping an {@link org.slf4j.Logger} instance preserving
+ * location information if the wrapped instance supports it.
  * 
  * @author Ralph Goers
  * @author Ceki G&uuml;lc&uuml;
  */
 public class LoggerWrapper implements Logger {
 
-  // To ensure consistency between two instances sharing the same name (homonyms)
-  // a LoggerWrapper should not contain any state beyond 
+  // To ensure consistency between two instances sharing the same name
+  // (homonyms)
+  // a LoggerWrapper should not contain any state beyond
   // the Logger instance it wraps.
   // Note that 'instanceofLAL' directly depends on Logger.
   // fqcn depend on the caller, but its value would not be different
   // between successive invocations of a factory class
-  
+
   protected final Logger logger;
   final String fqcn;
   // is this logger instance a LocationAwareLogger
   protected final boolean instanceofLAL;
-  
+
   public LoggerWrapper(Logger logger, String fqcn) {
     this.logger = logger;
     this.fqcn = fqcn;
@@ -36,7 +61,7 @@ public class LoggerWrapper implements Logger {
       instanceofLAL = false;
     }
   }
-  
+
   /**
    * Delegate to the appropriate method of the underlying logger.
    */
@@ -60,7 +85,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.TRACE_INT, msg, null);
+          LocationAwareLogger.TRACE_INT, msg, null, null);
     } else {
       logger.trace(msg);
     }
@@ -74,9 +99,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.TRACE_INT, formattedMessage, null);
+          LocationAwareLogger.TRACE_INT, formattedMessage,
+          new Object[] { arg }, null);
     } else {
       logger.trace(format, arg);
     }
@@ -90,9 +117,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.TRACE_INT, formattedMessage, null);
+          LocationAwareLogger.TRACE_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.trace(format, arg1, arg2);
     }
@@ -106,9 +135,10 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.TRACE_INT, formattedMessage, null);
+          LocationAwareLogger.TRACE_INT, formattedMessage, argArray, null);
     } else {
       logger.trace(format, argArray);
     }
@@ -123,7 +153,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.TRACE_INT, msg, t);
+          LocationAwareLogger.TRACE_INT, msg, null, t);
     } else {
       logger.trace(msg, t);
     }
@@ -137,7 +167,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.TRACE_INT, msg, null);
+          LocationAwareLogger.TRACE_INT, msg, null, null);
     } else {
       logger.trace(marker, msg);
     }
@@ -150,9 +180,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isTraceEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.TRACE_INT, formattedMessage, null);
+          LocationAwareLogger.TRACE_INT, formattedMessage,
+          new Object[] { arg }, null);
     } else {
       logger.trace(marker, format, arg);
     }
@@ -165,9 +197,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isTraceEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.TRACE_INT, formattedMessage, null);
+          LocationAwareLogger.TRACE_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.trace(marker, format, arg1, arg2);
     }
@@ -180,9 +214,10 @@ public class LoggerWrapper implements Logger {
     if (!logger.isTraceEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.TRACE_INT, formattedMessage, null);
+          LocationAwareLogger.TRACE_INT, formattedMessage, argArray, null);
     } else {
       logger.trace(marker, format, argArray);
     }
@@ -196,7 +231,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.TRACE_INT, msg, t);
+          LocationAwareLogger.TRACE_INT, msg, null, t);
     } else {
       logger.trace(marker, msg, t);
     }
@@ -225,7 +260,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.DEBUG_INT, msg, null);
+          LocationAwareLogger.DEBUG_INT, msg, null, null);
     } else {
       logger.debug(msg);
     }
@@ -239,9 +274,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.DEBUG_INT, formattedMessage, null);
+          LocationAwareLogger.DEBUG_INT, formattedMessage,
+          new Object[] { arg }, null);
     } else {
       logger.debug(format, arg);
     }
@@ -255,9 +292,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.DEBUG_INT, formattedMessage, null);
+          LocationAwareLogger.DEBUG_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.debug(format, arg1, arg2);
     }
@@ -271,9 +310,10 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      FormattingTuple ft = MessageFormatter.arrayFormat(format, argArray);
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.DEBUG_INT, formattedMessage, null);
+          LocationAwareLogger.DEBUG_INT, ft.getMessage(), ft.getArgArray(), ft
+              .getThrowable());
     } else {
       logger.debug(format, argArray);
     }
@@ -288,7 +328,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.DEBUG_INT, msg, t);
+          LocationAwareLogger.DEBUG_INT, msg, null, t);
     } else {
       logger.debug(msg, t);
     }
@@ -302,7 +342,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.DEBUG_INT, msg, null);
+          LocationAwareLogger.DEBUG_INT, msg, null, null);
     } else {
       logger.debug(marker, msg);
     }
@@ -315,9 +355,10 @@ public class LoggerWrapper implements Logger {
     if (!logger.isDebugEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      FormattingTuple ft = MessageFormatter.format(format, arg);
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.DEBUG_INT, formattedMessage, null);
+          LocationAwareLogger.DEBUG_INT, ft.getMessage(), ft.getArgArray(), ft
+              .getThrowable());
     } else {
       logger.debug(marker, format, arg);
     }
@@ -330,9 +371,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isDebugEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.DEBUG_INT, formattedMessage, null);
+          LocationAwareLogger.DEBUG_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.debug(marker, format, arg1, arg2);
     }
@@ -345,9 +388,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isDebugEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+
+      FormattingTuple ft = MessageFormatter.arrayFormat(format, argArray);
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.DEBUG_INT, formattedMessage, null);
+          LocationAwareLogger.DEBUG_INT, ft.getMessage(), argArray, ft
+              .getThrowable());
     } else {
       logger.debug(marker, format, argArray);
     }
@@ -361,7 +406,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.DEBUG_INT, msg, t);
+          LocationAwareLogger.DEBUG_INT, msg, null, t);
     } else {
       logger.debug(marker, msg, t);
     }
@@ -390,7 +435,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.INFO_INT, msg, null);
+          LocationAwareLogger.INFO_INT, msg, null, null);
     } else {
       logger.info(msg);
     }
@@ -404,9 +449,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.INFO_INT, formattedMessage, null);
+          LocationAwareLogger.INFO_INT, formattedMessage, new Object[] { arg },
+          null);
     } else {
       logger.info(format, arg);
     }
@@ -420,9 +467,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.INFO_INT, formattedMessage, null);
+          LocationAwareLogger.INFO_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.info(format, arg1, arg2);
     }
@@ -436,9 +485,10 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.INFO_INT, formattedMessage, null);
+          LocationAwareLogger.INFO_INT, formattedMessage, argArray, null);
     } else {
       logger.info(format, argArray);
     }
@@ -453,7 +503,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.INFO_INT, msg, t);
+          LocationAwareLogger.INFO_INT, msg, null, t);
     } else {
       logger.info(msg, t);
     }
@@ -467,7 +517,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.INFO_INT, msg, null);
+          LocationAwareLogger.INFO_INT, msg, null, null);
     } else {
       logger.info(marker, msg);
     }
@@ -480,9 +530,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isInfoEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.INFO_INT, formattedMessage, null);
+          LocationAwareLogger.INFO_INT, formattedMessage, new Object[] { arg },
+          null);
     } else {
       logger.info(marker, format, arg);
     }
@@ -495,9 +547,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isInfoEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.INFO_INT, formattedMessage, null);
+          LocationAwareLogger.INFO_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.info(marker, format, arg1, arg2);
     }
@@ -510,9 +564,10 @@ public class LoggerWrapper implements Logger {
     if (!logger.isInfoEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.INFO_INT, formattedMessage, null);
+          LocationAwareLogger.INFO_INT, formattedMessage, argArray, null);
     } else {
       logger.info(marker, format, argArray);
     }
@@ -526,7 +581,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.INFO_INT, msg, t);
+          LocationAwareLogger.INFO_INT, msg, null, t);
     } else {
       logger.info(marker, msg, t);
     }
@@ -552,7 +607,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.WARN_INT, msg, null);
+          LocationAwareLogger.WARN_INT, msg, null, null);
     } else {
       logger.warn(msg);
     }
@@ -566,9 +621,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.WARN_INT, formattedMessage, null);
+          LocationAwareLogger.WARN_INT, formattedMessage, new Object[] { arg },
+          null);
     } else {
       logger.warn(format, arg);
     }
@@ -582,9 +639,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.WARN_INT, formattedMessage, null);
+          LocationAwareLogger.WARN_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.warn(format, arg1, arg2);
     }
@@ -598,9 +657,10 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.WARN_INT, formattedMessage, null);
+          LocationAwareLogger.WARN_INT, formattedMessage, argArray, null);
     } else {
       logger.warn(format, argArray);
     }
@@ -615,7 +675,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.WARN_INT, msg, t);
+          LocationAwareLogger.WARN_INT, msg, null, t);
     } else {
       logger.warn(msg, t);
     }
@@ -629,7 +689,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.WARN_INT, msg, null);
+          LocationAwareLogger.WARN_INT, msg, null, null);
     } else {
       logger.warn(marker, msg);
     }
@@ -642,9 +702,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isWarnEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.WARN_INT, formattedMessage, null);
+          LocationAwareLogger.WARN_INT, formattedMessage, new Object[] { arg },
+          null);
     } else {
       logger.warn(marker, format, arg);
     }
@@ -657,9 +719,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isWarnEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.WARN_INT, formattedMessage, null);
+          LocationAwareLogger.WARN_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.warn(marker, format, arg1, arg2);
     }
@@ -672,9 +736,10 @@ public class LoggerWrapper implements Logger {
     if (!logger.isWarnEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.WARN_INT, formattedMessage, null);
+          LocationAwareLogger.WARN_INT, formattedMessage, argArray, null);
     } else {
       logger.warn(marker, format, argArray);
     }
@@ -688,7 +753,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.WARN_INT, msg, t);
+          LocationAwareLogger.WARN_INT, msg, null, t);
     } else {
       logger.warn(marker, msg, t);
     }
@@ -717,7 +782,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.ERROR_INT, msg, null);
+          LocationAwareLogger.ERROR_INT, msg, null, null);
     } else {
       logger.error(msg);
     }
@@ -731,9 +796,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.ERROR_INT, formattedMessage, null);
+          LocationAwareLogger.ERROR_INT, formattedMessage,
+          new Object[] { arg }, null);
     } else {
       logger.error(format, arg);
     }
@@ -747,9 +814,11 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.ERROR_INT, formattedMessage, null);
+          LocationAwareLogger.ERROR_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.error(format, arg1, arg2);
     }
@@ -763,9 +832,10 @@ public class LoggerWrapper implements Logger {
       return;
 
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.ERROR_INT, formattedMessage, null);
+          LocationAwareLogger.ERROR_INT, formattedMessage, argArray, null);
     } else {
       logger.error(format, argArray);
     }
@@ -780,7 +850,7 @@ public class LoggerWrapper implements Logger {
 
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(null, fqcn,
-          LocationAwareLogger.ERROR_INT, msg, t);
+          LocationAwareLogger.ERROR_INT, msg, null, t);
     } else {
       logger.error(msg, t);
     }
@@ -794,7 +864,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.ERROR_INT, msg, null);
+          LocationAwareLogger.ERROR_INT, msg, null, null);
     } else {
       logger.error(marker, msg);
     }
@@ -807,9 +877,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isErrorEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg);
+      String formattedMessage = MessageFormatter.format(format, arg)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.ERROR_INT, formattedMessage, null);
+          LocationAwareLogger.ERROR_INT, formattedMessage,
+          new Object[] { arg }, null);
     } else {
       logger.error(marker, format, arg);
     }
@@ -822,9 +894,11 @@ public class LoggerWrapper implements Logger {
     if (!logger.isErrorEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.format(format, arg1, arg2);
+      String formattedMessage = MessageFormatter.format(format, arg1, arg2)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.ERROR_INT, formattedMessage, null);
+          LocationAwareLogger.ERROR_INT, formattedMessage, new Object[] { arg1,
+              arg2 }, null);
     } else {
       logger.error(marker, format, arg1, arg2);
     }
@@ -837,9 +911,10 @@ public class LoggerWrapper implements Logger {
     if (!logger.isErrorEnabled())
       return;
     if (instanceofLAL) {
-      String formattedMessage = MessageFormatter.arrayFormat(format, argArray);
+      String formattedMessage = MessageFormatter.arrayFormat(format, argArray)
+          .getMessage();
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.ERROR_INT, formattedMessage, null);
+          LocationAwareLogger.ERROR_INT, formattedMessage, argArray, null);
     } else {
       logger.error(marker, format, argArray);
     }
@@ -853,7 +928,7 @@ public class LoggerWrapper implements Logger {
       return;
     if (instanceofLAL) {
       ((LocationAwareLogger) logger).log(marker, fqcn,
-          LocationAwareLogger.ERROR_INT, msg, t);
+          LocationAwareLogger.ERROR_INT, msg, null, t);
     } else {
       logger.error(marker, msg, t);
     }
